@@ -144,10 +144,10 @@ pub fn init() -> BetterResult<Config> {
     // Make sure to also edit the `default.env` if you introduce / change environment variables here.
     for (key, value) in env::vars() {
         match &*key {
-            "ATOMIC_CONFIG_DIR" => {
+            "ATOMIC_CONFIG_FILE_PATH" => {
                 config_file_path = value.parse().map_err(|e| {
                     format!(
-                        "Could not parse ATOMIC_CONFIG_DIR. Is {} a valid path? {}",
+                        "Could not parse ATOMIC_CONFIG_FILE_PATH. Is {} a valid path? {}",
                         value, e
                     )
                 })?;
